// Load data from the CSV file
d3.csv(
  'https://gist.githubusercontent.com/SirishaManthena/143d8a4e801946f7437aec508d8f5254/raw/c138d08f102c2b8c7d61957ef9dba2d25e37cf42/nutritionalinfo.csv',
)
  .then(function (data) {
    // Filter data for the top best-selling items
    const topItems = data.filter(function (d) {
      return (
        d.Item === 'Egg McMuffin' ||
        d.Item === 'Big Mac' ||
        d.Item === 'Hamburger' ||
        d.Item === 'Cheeseburger' ||
        d.Item === 'Double Cheeseburger' ||
        d.Item === 'McChicken' ||
        d.Item === 'Chicken McNuggets (10 piece)' ||
        d.Item === 'Filet-O-Fish' ||
        d.Item === 'Large French Fries' ||
        d.Item === 'Hot Fudge Sundae'
      );
    });

    // Extract item names and calories
    const itemNames = topItems.map(function (d) {
      return d.Item;
    });
    const calories = topItems.map(function (d) {
      return parseFloat(d.Calories); // Parse calories as float
    });

    // Dimensions and radius of the pie chart
    const width = 900; // Increased width further
    const height = 400;
    const radius = Math.min(width, height) / 2;

    // Create SVG element
    const svg = d3
      .select('#pieChart')
      .append('svg')
      .attr('width', width)
      .attr('height', height)
      .style('margin-top', '20px'); // Add margin at the top

    // Define color scale
    const color = d3
      .scaleOrdinal()
      .domain(itemNames)
      .range([
        '#ffcc00',
        '#ff6666',
        '#ff4d4d',
        '#66ccff',
        '#ff99cc',
        '#66ff66',
        '#ff9933',
        '#9966ff',
        '#ff9966',
        '#cc99ff',
      ]);

    // Define pie function
    const pie = d3.pie().value(function (d) {
      return d;
    });

    // Define arc function
    const arc = d3.arc().innerRadius(0).outerRadius(radius);

    // Create pie chart
    const arcs = svg
      .selectAll('arc')
      .data(pie(calories))
      .enter()
      .append('g')
      .attr(
        'transform',
        `translate(${width / 3},${height / 2})`, // Move to the left side
      );

    arcs
      .append('path')
      .attr('d', arc)
      .attr('fill', function (d, i) {
        return color(itemNames[i]);
      });

    // Add legend
    const legend = svg
      .append('g')
      .attr('class', 'legend')
      .attr(
        'transform',
        `translate(${(width * 2) / 3}, 20)`,
      ); // Move to the right side

    legend
      .selectAll('.legend-item')
      .data(itemNames)
      .enter()
      .append('g')
      .attr('class', 'legend-item')
      .attr('transform', function (d, i) {
        return 'translate(0,' + i * 35 + ')';
      })
      .each(function (d, i) {
        const legendItem = d3.select(this);
        legendItem
          .append('rect')
          .attr('x', 0)
          .attr('width', 18)
          .attr('height', 18)
          .style('fill', color(itemNames[i]));

        legendItem
          .append('text')
          .attr('x', 25)
          .attr('y', 9)
          .attr('dy', '.35em')
          .style('font-family', 'Arial, sans-serif')
          .style('font-size', '13px')
          .style('text-anchor', 'start')
          .text(d + ' - ' + calories[i] + ' calories');
      });
  })
  .catch(function (error) {
    console.log(error);
  });

// Add title above the SVG
d3.select('#pieChart')
  .append('h3')
  .text(
    "Calorie Count for Top 10 Best Selling Items of McDonald's",
  )
  .style('text-align', 'center');
